pub enum Interrupted<P>where
P: Share,{
OsSignal,
User {
payload: Option<P>,
},
}Expand description
An Interrupt message that is produced by either an OS signal (e.g. kill)
or the user by requesting the application to close.
Variants