Store

Struct Store 

pub struct Store<S, M, R>
where S: Update<M, Return = R> + Share,
{ /* private fields */ }
The Store updates the applications’ state concurrently. It handles messages coming from the frontend and updates the state accordingly.

Implementations

Source

impl<S, M, R> Store<S, M, R>
where S: Update<M, Return = R> + Share, R: Share,

pub fn new(tx: UnboundedSender<S>) -> Self

Source

impl<S, M, R> Store<S, M, R>
where S: Update<M, Return = R> + Share, M: Share, R: Share,

pub async fn run( self, state: S, terminator: Terminator<R>, message_rx: Receiver<M>, work_rx: UnboundedReceiver<M>, interrupt_rx: Receiver<Interrupted<R>>, ) -> Result<Interrupted<R>>

By calling main_loop, the store will wait for new messages coming from the frontend and update the applications’ state accordingly. It will also tick with the defined STORE_TICK_RATE. Updated states are then being send to the state message channel.