Process

Trait Process 

pub trait Process<M: Share> {
    // Required method
    fn process(
        &mut self,
        _message: M,
    ) -> impl Future<Output = Result<Vec<M>>> + Send;
}
A processor that can be added to the application environment. Processors will receive application messages and can produce new ones.

Required Methods

fn process( &mut self, _message: M, ) -> impl Future<Output = Result<Vec<M>>> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors