Layout

Enum Layout 

pub enum Layout {
    None,
    Wrapped {
        internal: Layout,
    },
    Expandable3 {
        left_only: bool,
    },
    Popup {
        percent_x: u16,
        percent_y: u16,
    },
}
A Layout is used to support pre-defined layouts. It either represents such a predefined layout or a wrapped ratatui layout. It’s used internally but can be build from a ratatui layout.

Variants



None



Wrapped

Fields

internal: Layout


Expandable3

Fields

left_only: bool


Popup

Fields

percent_x: u16
percent_y: u16

Implementations

Source

impl Layout

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn split(&self, area: Rect) -> Rc<[Rect]>