pub struct Store<S, M, R>{ /* private fields */ }Expand description
The Store updates the applications’ state concurrently. It handles
messages coming from the frontend and updates the state accordingly.
Implementations
Sourceimpl<S, M, R> Store<S, M, R>
impl<S, M, R> Store<S, M, R>
Sourcepub async fn run(
self,
state: S,
terminator: Terminator<R>,
message_rx: Receiver<M>,
work_rx: UnboundedReceiver<M>,
interrupt_rx: Receiver<Interrupted<R>>,
) -> Result<Interrupted<R>>
pub async fn run( self, state: S, terminator: Terminator<R>, message_rx: Receiver<M>, work_rx: UnboundedReceiver<M>, interrupt_rx: Receiver<Interrupted<R>>, ) -> Result<Interrupted<R>>
By calling main_loop, the store will wait for new messages coming
from the frontend and update the applications’ state accordingly. It will
also tick with the defined STORE_TICK_RATE.
Updated states are then being send to the state message channel.